@@ -20,7 +20,7 @@
 from __future__ import absolute_import
 from __future__ import with_statement
 
-VERSION = (2, 7, 3, 32)
+VERSION = (2, 7, 3, 33)
 __version__ = ".".join(map(str, VERSION[0:4])) + "".join(VERSION[4:])
 __author__ = 'R Oudkerk / Python Software Foundation'
 __author_email__ = 'python-dev@python.org'
@@ -97,7 +97,7 @@ def Pipe(duplex=True):
     if sys.version_info[0] == 3:
         from multiprocessing.connection import Pipe
     else:
-        from billiard._connection import Pipe
+        from billiard._connection import Pipe  # noqa
     return Pipe(duplex)
 
 
